@@ -1,3 +1,4 @@
+import pathlib
 from typing import Union
 from pathlib import Path
 import os
@@ -7,8 +8,16 @@ from google.cloud import storage
 
 from tqdm import tqdm
 
-credentials = service_account.Credentials.from_service_account_file(os.getenv('GCLOUD_CREDENTIALS', input('abs path to GCP credentials: ')))
-client = storage.Client(project=os.getenv('GCLOUD_PROJECT', input('GCLOUD_PROJECT: ')), credentials=credentials)
+creds_path = os.getenv('GCLOUD_CREDENTIALS')
+if not creds_path:
+    creds_path = input('abs path to GCP credentials:')
+
+gcloud_project = os.getenv('GCLOUD_PROJECT')
+if not gcloud_project:
+    gcloud_project = input('GCLOUD_PROJECT: ')
+
+credentials = service_account.Credentials.from_service_account_file(creds_path)
+client = storage.Client(project=gcloud_project, credentials=credentials)
 
 
 def set_gcp_creds(project_name: str, path_to_creds: Union[Path, str]) -> storage.Client:
@@ -46,12 +55,15 @@ def download_gs_folder(bucket, gs_path, dst_path, client=client):
     print("DONE")
 
 
-def rename_blob(blob: storage.blob.Blob, new_name, client=client):
+def rename_blob(blob: storage.blob.Blob, new_name: Union[str, pathlib.Path], client=client):
     """Renames a blob."""
     # bucket_name = "your-bucket-name"
     # blob_name = "your-object-name"
     # new_name = "new-object-name"
 
+    if isinstance(new_name, pathlib.Path):
+        new_name = str(new_name)
+
     bucket = client.bucket(blob.bucket.name)
 
     new_blob = bucket.rename_blob(blob, new_name)
